@@ -3,7 +3,7 @@
   Abstract : ExifData write unit tests
 
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
-  Version  : $Rev: 1512 $
+  Version  : $Rev: 2286 $
 
   Test procedure:
    $ rm -f test.jpg thumb.jpg iii ttt;
@@ -15,8 +15,7 @@
  */
 // *****************************************************************************
 // included header files
-#include <exiv2/image.hpp>
-#include <exiv2/exif.hpp>
+#include <exiv2/exiv2.hpp>
 
 #include <iostream>
 #include <sstream>
